@@ -20,6 +20,15 @@ sub disttest {
     my @missing    = manicheck;
     my @extra      = filecheck;
 
+    # I'm getting sick of making MANIFEST.SKIP files just for the
+    # .shipit conf file and dh-make-perl stuff, so let's ignore those
+    my %ignore = map { $_ => 1 } qw(
+                                    .shipit
+                                    install-stamp
+                                    build-stamp
+                                    );
+    @extra = grep { ! $ignore{$_} } @extra;
+
     my $list = sub {
         join('', map { "$_\n" } @_);
     };
